#
# This is the SPEC file for creating binary and source RPMs for the Qubes DB.
#
#
# The Qubes OS Project, http://www.qubes-os.org
#
# Copyright (C) 2013  Marek Marczykowski <marmarek@invisiblethingslab.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
#

# Package contains /usr/lib, but not binary files, which confuses find-debuginfo.sh script.
%global debug_package %{nil}

%global qubes_db_vm_selinux %{_datadir}/selinux/packages/qubes-core-qubesdb.pp

Name:		qubes-db-vm
Version:	4.2.1
Release:	1%{?dist}
Summary:	QubesDB VM service

Group:		Qubes
License:	GPL
URL:		http://www.qubes-os.org/

Requires:	qubes-db
Requires(post): /usr/bin/systemctl
%{?systemd_requires}
BuildRequires: systemd

Source0: qubes-db-%{version}.tar.gz

Requires: (%{name}-selinux if selinux-policy)
%package selinux

BuildRequires: selinux-policy
BuildRequires: selinux-policy-devel
%{?selinux_requires}
Requires: qubes-core-agent-selinux

Summary: SELinux policies for qubesdb
License: GPLv2+

%description selinux
The SELinux policies for qubesdb.  You need this package if you want to have
SELinux enforcing in a qube.

%files selinux
%{_datadir}/selinux/devel/include/contrib/ipp-qubes-core-qubesdb.if
%{qubes_db_vm_selinux}

%post selinux
%selinux_modules_install %{qubes_db_vm_selinux}

%postun selinux
if [ "$1" -eq 0 ]; then
    %selinux_modules_uninstall %{qubes_db_vm_selinux}
fi || :

%posttrans selinux
%selinux_relabel_post
exit 0

%description
QubesDB daemon service.

%prep
%setup -q -n qubes-db-%{version}

%build
make -f /usr/share/selinux/devel/Makefile -C selinux

%install
install -d %{buildroot}%{_unitdir}
install -p -m 644 daemon/qubes-db.service %{buildroot}%{_unitdir}/

install -m 0644 -D selinux/qubes-core-qubesdb.if %{buildroot}%{_datadir}/selinux/devel/include/contrib/ipp-qubes-core-qubesdb.if
install -m 0644 -D -t %{buildroot}%{_datadir}/selinux/packages selinux/qubes-core-qubesdb.pp

%post
%systemd_post qubes-db.service

%preun
%systemd_preun qubes-db.service

%postun
%systemd_postun_with_restart qubes-db.service

%files
%doc
%{_unitdir}/qubes-db.service

%changelog
* Mon Jan 09 2023 Qubes OS Team <qubes-devel@googlegroups.com>
- For complete changelog see: https://github.com/QubesOS/qubes-core-qubesdb

* Mon Jan 09 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - aca66da
- version 4.2.1

* Mon Jan 09 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 512566a
- rpm,debian: remove explicit dependency on vchan

* Thu Dec 29 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 56e446a
- version 4.2.0

* Wed Dec 21 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - a202584
- Add write permission to qubesdb-daemon on var_run_t

* Wed Dec 21 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - e825d37
- Avoid explicit mkdir

* Wed Dec 21 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 7aea4b8
- Simplify SELinux policy

* Wed Dec 21 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 924383f
- SELinux policies require qubes-core-agent-selinux

* Wed Dec 21 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - b959baf
- Simplify daemon startup and fix UB

* Wed Dec 21 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 80a3cc8
- Try to get qubesdb working with SELinux enforcing

* Wed Dec 21 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - a395852
- Implement SELinux policy for QubesDB

* Sat Dec 17 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - a8cab70
- Do not use select(2)

* Sat Dec 17 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 1aba6b5
- version 4.1.15

* Sat Dec 17 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 1c5c88a
- Fix some Doxygen comments

* Fri Dec 16 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 329c59d
- debian: remove remaining python2 dep

* Sun Oct 16 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 9743538
- Fix qubesdb-read-bool on missing keys

* Tue Oct 11 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 37c8c27
- version 4.1.14

* Mon May 09 2022 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 9f65b84
- .qubesbuilder: replace 'spec' by 'build'

* Mon Apr 25 2022 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - d327cb8
- Add Qubes Builder v2 integration

* Fri Apr 15 2022 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 0c4a7c4
- Drop Travis CI

* Sat Apr 09 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - e94f2c9
- Fix mingw build

* Mon Mar 21 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 13801fe
- ci: build on windows too

* Tue Mar 08 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 5399147
- Fix OSS Fuzz integration

* Sat Mar 05 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 4831306
- version 4.1.13

* Sat Mar 05 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - b9870c9
- CLI tools: distinguish "no such entry" and "error"

* Thu Mar 03 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 892cde0
- Reserve ENOENT for "no such path in QubesDB"

* Thu Mar 03 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 55fd470
- Write error messages if fflush() fails

* Thu Mar 03 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 484f173
- Better error checking when writing to stdout

* Thu Mar 03 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - e6c1516
- Daemon: Zeroize memory before freeing it

* Thu Mar 03 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 00ad65e
- Securely zero buffer memory before freeing it

* Thu Mar 03 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 31038b5
- Fix an unchecked malloc

* Thu Mar 03 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - f3db5c1
- Move newline printing to common code

* Thu Mar 03 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 1ddb48c
- Forbid leading dashes in qubesdb entry names

* Thu Mar 03 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - ec06222
- Add documentation for -h

* Thu Mar 03 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 32a28ea
- Fix error checking and a memory leak

* Thu Mar 03 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 203725e
- Exit non-zero on I/O errors

* Thu Mar 03 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - ca0dc1f
- Allow removing a value after reading it

* Thu Mar 03 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 7e9c0b7
- Add a comma after enum variant

* Thu Mar 03 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 015adec
- Fix build with -Werror=missing-prototypes

* Thu Jan 06 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - cb6f143
- windows: add locking

* Thu Jan 06 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 704b136
- windows: add missing handle_client_disconnect call

* Wed Jan 05 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 1308c96
- Add assertions to detect FD_SET overflow

* Wed Jan 05 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 4f9dfb3
- version 4.1.12

* Thu Dec 30 2021 Mikhail Lukashov <mlukashov@tabit.pro> - 198be9d
- windows: fix qubesdb-daemon cleanup on shutdown

* Thu Dec 30 2021 Ivan Kardykov <kardykov@tabit.pro> - 6a34e2f
- windows: fix incompartible unicode with MinGW

* Thu Dec 30 2021 Mikhail Lukashov <mlukashov@tabit.pro> - 3cfe981
- windows: remove duplicated error logging

* Thu Dec 30 2021 Mikhail Lukashov <mlukashov@tabit.pro> - 22095ff
- windows: improve logging

* Thu Dec 30 2021 Mikhail Lukashov <mlukashov@tabit.pro> - 9a12fc3
- windows: build fixups to VS2019

* Wed Dec 29 2021 Ivan Kardykov <kardykov@tabit.pro> - 215f639
- fix win32 compilation

* Mon Dec 27 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 6c75f00
- windows: rename perror to win_perror

* Mon Dec 27 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 08ccd54
- Add Makefile for MinGW build

